@@ -53,6 +53,15 @@ merge.minidesc_tag <- function(x, y, ...) {
   list(x)
 }
 
+# Comment tags -----------------------------------------------------------------------
+
+#' @export
+format.srcref_tag <- function(x, ...) {
+  filename <- unique(x$values)
+  filename <- file.path(basename(dirname(filename)), basename(filename), fsep = "/")
+  sprintf("%% Please edit documentation in %s\n", paste(filename, collapse = ", "))
+}
+
 # Tags that repeat multiple times --------------------------------------------
 
 format_rd <- function(x, ...) {
